@@ -114,7 +114,7 @@ QMediaPlayer::Error AudioManager::error() const
 {
     if (d->m_player.error() != QMediaPlayer::NoError) {
         qCDebug(kastsAudio) << "AudioManager::error" << d->m_player.errorString();
-        // Some error occured: probably best to unset the lastPlayingEntry to
+        // Some error occurred: probably best to unset the lastPlayingEntry to
         // avoid a deadlock when starting up again.
         DataManager::instance().setLastPlayingEntry(QStringLiteral("none"));
     }
@@ -234,7 +234,7 @@ void AudioManager::setEntry(Entry *entry)
                                   + QStringLiteral(" audio_sink=\"scaletempo ! audioconvert ! audioresample ! autoaudiosink\" video_sink=\"fakevideosink\"")));
 #else
         qCDebug(kastsAudio) << "regular audio backend";
-        d->m_player.setMedia(QUrl(QStringLiteral("file://") + d->m_entry->enclosure()->path()));
+        d->m_player.setMedia(QUrl::fromLocalFile(d->m_entry->enclosure()->path()));
 #endif
         // save the current playing track in the settingsfile for restoring on startup
         DataManager::instance().setLastPlayingEntry(d->m_entry->id());
