@@ -17,6 +17,7 @@
 #include <memory>
 
 #include "entry.h"
+#include "error.h"
 
 class AudioManagerPrivate;
 
@@ -131,6 +132,8 @@ Q_SIGNALS:
 
     void canGoNextChanged();
 
+    void logError(Error::Type type, const QString &url, const QString &id, const int errorId, const QString &errorString, const QString &title);
+
 public Q_SLOTS:
 
     void setEntry(Entry *entry);
@@ -167,11 +170,17 @@ private Q_SLOTS:
 
     void playerStateChanged();
 
+    void playerDurationChanged(qint64 duration);
+
     void playerMutedChanged();
 
     void playerVolumeChanged();
 
-    void savePlayPosition(qint64 position);
+    void savePlayPosition();
+
+    void prepareAudio();
+
+    void checkForPendingSeek();
 
 private:
     explicit AudioManager(QObject *parent = nullptr);
