@@ -52,6 +52,10 @@ QString Error::description() const
         return i18n("Update Not Allowed on Metered Connection");
     case Error::Type::InvalidMedia:
         return i18n("Invalid Media File");
+    case Error::Type::DiscoverError:
+        return i18n("Nothing Found");
+    case Error::Type::StorageMoveError:
+        return i18n("Error moving storage path");
     default:
         return QString();
     }
@@ -68,6 +72,10 @@ int Error::typeToDb(Error::Type type)
         return 2;
     case Error::Type::InvalidMedia:
         return 3;
+    case Error::Type::DiscoverError:
+        return 4;
+    case Error::Type::StorageMoveError:
+        return 5;
     default:
         return -1;
     }
@@ -84,6 +92,10 @@ Error::Type Error::dbToType(int value)
         return Error::Type::MeteredNotAllowed;
     case 3:
         return Error::Type::InvalidMedia;
+    case 4:
+        return Error::Type::DiscoverError;
+    case 5:
+        return Error::Type::StorageMoveError;
     default:
         return Error::Type::Unknown;
     }
