@@ -21,6 +21,8 @@ public:
         MediaDownload,
         MeteredNotAllowed,
         InvalidMedia,
+        DiscoverError,
+        StorageMoveError,
     };
     Q_ENUM(Type)
 
