@@ -5,8 +5,9 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#include "fetcher.h"
+
 #include <KLocalizedString>
-#include <QCryptographicHash>
 #include <QDateTime>
 #include <QDebug>
 #include <QDir>
@@ -16,17 +17,16 @@
 #include <QMultiMap>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
-#include <QStandardPaths>
 #include <QTextDocumentFragment>
 
 #include <Syndication/Syndication>
 
 #include "database.h"
 #include "enclosure.h"
-#include "fetcher.h"
 #include "fetcherlogging.h"
 #include "kasts-version.h"
 #include "settingsmanager.h"
+#include "storagemanager.h"
 
 Fetcher::Fetcher()
 {
@@ -303,8 +303,11 @@ bool Fetcher::processEntry(Syndication::ItemPtr entry, const QString &url, bool
             processAuthor(url, entry->id(), authorName, QLatin1String(""), QLatin1String(""));
     }
 
-    for (const auto &enclosure : entry->enclosures()) {
-        processEnclosure(enclosure, entry, url);
+    // only process first enclosure if there are multiple (e.g. mp3 and ogg);
+    // the first one is probably the podcast author's preferred version
+    // TODO: handle more than one enclosure?
+    if (entry->enclosures().count() > 0) {
+        processEnclosure(entry->enclosures()[0], entry, url);
     }
 
     Q_EMIT entryAdded(url, entry->id());
@@ -344,7 +347,10 @@ void Fetcher::processEnclosure(Syndication::EnclosurePtr enclosure, Syndication:
     query.next();
 
     if (query.value(0).toInt() != 0)
-        query.prepare(QStringLiteral("UPDATE Enclosures SET feed=:feed, id=:id, duration=:duration, size=:size, title=:title, type=:type, url=:url;"));
+        query.prepare(QStringLiteral(
+            "UPDATE Enclosures SET feed=:feed, id=:id, duration=:duration, size=:size, title=:title, type=:type, url=:url WHERE feed=:feed AND id=:id;"));
+    // NOTE: In case more than one enclosure is present per episode, only
+    // the last one will end up in the database
     else
         query.prepare(QStringLiteral("INSERT INTO Enclosures VALUES (:feed, :id, :duration, :size, :title, :type, :url, :playposition, :downloaded);"));
 
@@ -367,10 +373,10 @@ QString Fetcher::image(const QString &url) const
     }
 
     // if image is already cached, then return the path
-    QString path = imagePath(url);
+    QString path = StorageManager::instance().imagePath(url);
     if (QFileInfo::exists(path)) {
         if (QFileInfo(path).size() != 0) {
-            return QStringLiteral("file://") + path;
+            return QUrl::fromLocalFile(path).toString();
         }
     }
 
@@ -450,28 +456,6 @@ QNetworkReply *Fetcher::download(const QString &url, const QString &filePath) co
     return reply;
 }
 
-void Fetcher::removeImage(const QString &url)
-{
-    qCDebug(kastsFetcher) << "Removing image" << imagePath(url);
-    QFile(imagePath(url)).remove();
-}
-
-QString Fetcher::imagePath(const QString &url) const
-{
-    QString path = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/images/");
-    // Create path in cache if it doesn't exist yet
-    QFileInfo().absoluteDir().mkpath(path);
-    return path + QString::fromStdString(QCryptographicHash::hash(url.toUtf8(), QCryptographicHash::Md5).toHex().toStdString());
-}
-
-QString Fetcher::enclosurePath(const QString &url) const
-{
-    QString path = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/enclosures/");
-    // Create path in cache if it doesn't exist yet
-    QFileInfo().absoluteDir().mkpath(path);
-    return path + QString::fromStdString(QCryptographicHash::hash(url.toUtf8(), QCryptographicHash::Md5).toHex().toStdString());
-}
-
 QNetworkReply *Fetcher::get(QNetworkRequest &request) const
 {
     setHeader(request);
